/*$DELIMITER:/ */
CREATE TABLE JCR_CONTAINER(
  VERSION VARCHAR(255) NOT NULL,
  CONSTRAINT JCR_PK_CONTAINER PRIMARY KEY(VERSION)
)
/
CREATE TABLE JCR_SITEM(
    ID VARCHAR2(255) NOT NULL,
    VERSION INTEGER NOT NULL,
    CONTAINER_NAME VARCHAR2(255) NOT NULL,
    PATH VARCHAR2(4000) NOT NULL,
  	CONSTRAINT JCR_PK_SITEM PRIMARY KEY(ID),
  	CONSTRAINT JCR_CU_SITEM_ID UNIQUE (ID, PATH, CONTAINER_NAME, VERSION)
		USING INDEX (CREATE UNIQUE INDEX JCR_IDX_SITEM_ID ON JCR_SITEM(ID, PATH, CONTAINER_NAME, VERSION) COMPUTE STATISTICS),
  	CONSTRAINT JCR_CU_SITEM_PATH UNIQUE (PATH, CONTAINER_NAME, ID, VERSION)
		USING INDEX (CREATE UNIQUE INDEX JCR_IDX_SITEM_PATH ON JCR_SITEM(PATH, CONTAINER_NAME, ID, VERSION) COMPUTE STATISTICS)
)
/
CREATE TABLE JCR_SNODE(
    ID VARCHAR2(255) NOT NULL,
    ORDER_NUM INTEGER,
    PARENT_ID VARCHAR2(255),
  	CONSTRAINT JCR_PK_SNODE PRIMARY KEY(ID),
    CONSTRAINT JCR_FK_SNODE_PARENT FOREIGN KEY(PARENT_ID) REFERENCES JCR_SNODE(ID),
    CONSTRAINT JCR_FK_SNODE_ITEM FOREIGN KEY(ID) REFERENCES JCR_SITEM(ID),
	CONSTRAINT JCR_CU_SNODE_PARENT UNIQUE (ID, PARENT_ID, ORDER_NUM)
		USING INDEX (CREATE UNIQUE INDEX JCR_IDX_SNODE_PARENT ON JCR_SNODE(ID, PARENT_ID, ORDER_NUM) COMPUTE STATISTICS),
	CONSTRAINT JCR_CU_SNODE_PARENTID UNIQUE (PARENT_ID, ID, ORDER_NUM)
		USING INDEX (CREATE UNIQUE INDEX JCR_IDX_SNODE_PARENTID ON JCR_SNODE(PARENT_ID, ID, ORDER_NUM) COMPUTE STATISTICS)
)
/
CREATE TABLE JCR_SPROPERTY(
    ID VARCHAR2(255) NOT NULL,
    TYPE INTEGER NOT NULL,
    PARENT_ID VARCHAR2(255) NOT NULL,
    MULTIVALUED INTEGER NOT NULL,
  	CONSTRAINT JCR_PK_SPROPERTY PRIMARY KEY(ID),
    CONSTRAINT JCR_FK_SPROPERTY_NODE FOREIGN KEY(PARENT_ID) REFERENCES JCR_SNODE(ID),
    CONSTRAINT JCR_FK_SPROPERTY_ITEM FOREIGN KEY(ID) REFERENCES JCR_SITEM(ID),
	CONSTRAINT JCR_CU_SPROPERTY_PARENT UNIQUE (ID, PARENT_ID)
		USING INDEX (CREATE UNIQUE INDEX JCR_IDX_SPROPERTY_PARENT ON JCR_SPROPERTY(ID, PARENT_ID) COMPUTE STATISTICS),
	CONSTRAINT JCR_CU_SPROPERTY_PARENTID UNIQUE (PARENT_ID, ID)
		USING INDEX (CREATE UNIQUE INDEX JCR_IDX_SPROPERTY_PARENTID ON JCR_SPROPERTY(PARENT_ID, ID) COMPUTE STATISTICS)
)
/
CREATE TABLE JCR_SVALUE(
    ID INTEGER,
    DATA BLOB,
    ORDER_NUM INTEGER,
    PROPERTY_ID VARCHAR2(255) NOT NULL,
	CONSTRAINT JCR_PK_SVALUE PRIMARY KEY(ID),
    CONSTRAINT JCR_FK_SVALUE_PROPERTY FOREIGN KEY(PROPERTY_ID) REFERENCES JCR_SPROPERTY(ID),
	CONSTRAINT JCR_CU_SVALUE_PROPERTY UNIQUE (PROPERTY_ID, ORDER_NUM)
		USING INDEX (CREATE UNIQUE INDEX JCR_IDX_SVALUE_PROPERTY ON JCR_SVALUE(PROPERTY_ID, ORDER_NUM) COMPUTE STATISTICS)
)
/
CREATE sequence JCR_SVALUE_SEQ
/
CREATE OR REPLACE trigger BI_JCR_SVALUE
  before insert on JCR_SVALUE
  for each row
begin
  SELECT JCR_SVALUE_SEQ.nextval INTO :NEW.ID FROM dual;
end;
/
CREATE TABLE JCR_SREF(
  NODE_ID VARCHAR(255) NOT NULL,
  PROPERTY_ID VARCHAR(255) NOT NULL,
  ORDER_NUM INTEGER NOT NULL,
  CONSTRAINT JCR_PK_SREF PRIMARY KEY(NODE_ID, PROPERTY_ID, ORDER_NUM),
  CONSTRAINT JCR_CU_SREF_PROPERTY UNIQUE (PROPERTY_ID, ORDER_NUM)
		USING INDEX (CREATE UNIQUE INDEX JCR_IDX_SREF_PROPERTY ON JCR_SREF(PROPERTY_ID, ORDER_NUM) COMPUTE STATISTICS)
)
/